Macroeco: Ecological pattern analysis in Python
-----------------------------------------------

Macroeco is a Python package that provides a comprehensive set of functions for analyzing empirical patterns in ecological data, predicting patterns from theory, and comparing empirical results to theory. Many major macroecological patterns can be analyzed using this package, including the species abundance distribution, the species and endemics area relationships, several measures of beta diversity, and many others.

Extensive documentation for macroeco, including detailed installation instructions, tutorials, and a reference guide, is available at http://macroeco.org. The most recent stable version of the macroeco package can be installed from PyPI (``pip install macroeco``). For users who do not program in Python, a standalone application called Macroeco Desktop, which provides most of the functionality of macroeco through a simple interface that requires no programming, is also available.  To download this standalone application, click on the **releases** tab at the top of the repository home page (or `this link <https://github.com/jkitzes/macroeco/releases>`_) and download the file ``MacroecoDesktop_Mac_Standalone.zip`` from the most current version.

The current version of macroeco is developed and maintained by Justin Kitzes (UC Berkeley) and Mark Wilber (UC Santa Barbara). Other contributors include Chloe Lewis and Ethan White. The development of macroeco has been supported by the National Science Foundation, the Gordon and Betty Moore Foundation, and the Berkeley Institute for Data Science.
